@@ -4,8 +4,8 @@
 #' Given the left-hand side and right-hand side as character vectors, generates a new
 #' [stats::formula()].
 #'
-#' @param lhs (`character(1)`)\cr
-#'   Left-hand side of formula.
+#' @param lhs (`character()`)\cr
+#'   Left-hand side of formula. Multiple elements will be collapsed with `" + "`.
 #' @param rhs (`character()`)\cr
 #'   Right-hand side of formula. Multiple elements will be collapsed with `" + "`.
 #' @param env (`environment()`)\cr
@@ -23,7 +23,7 @@ formulate = function(lhs = NULL, rhs = NULL, env = NULL) {
   if (length(rhs) == 0L) {
     rhs = "1"
   }
-  f = as.formula(sprintf("%s ~ %s", lhs, paste0(rhs, collapse = " + ")))
+  f = as.formula(sprintf("%s ~ %s", paste0(lhs, collapse = " + "), paste0(rhs, collapse = " + ")))
   environment(f) = env
   f
 }
